from .VariableUnitTest import VariableUnitTest


class TestTotAreaMeters(VariableUnitTest):

    def test_TotAreaMeters(self):
        pass  # no need to vectorize
        # z = self.z
        # np.testing.assert_array_almost_equal(
        #     TotAreaMeters.TotAreaMeters_f(),
        #     TotAreaMeters.TotAreaMeters(), decimal=7)
