from .VariableUnitTest import VariableUnitTest


class TestRetentFactorN(VariableUnitTest):
    pass
    # @skip("not ready")
    # def test_RetentFactorN(self):
    #     z = self.z
    #     np.testing.assert_array_almost_equal(
    #         RetentFactorN.RetentFactorN_2(),
    #         RetentFactorN.RetentFactorN(), decimal=7)
