from .VariableUnitTest import VariableUnitTest


class TestAgAreaTotal(VariableUnitTest):

    def test_AgAreaTotal(self):
        pass
        # z = self.z
        # np.testing.assert_array_almost_equal(
        #     AgAreaTotal.AgAreaTotal_f(z.Landuse, z.Area),
        #     AgAreaTotal.AgAreaTotal(z.NRur, z.Landuse, z.Area), decimal=7)
